<img align="left" width="250" height="250" src="https://i.imgur.com/8jqfpoz.png"> 

A small collection of examples on how to use our package. 

<br/>

These are the scripts used to created the examples in the [wiki page](https://github.com/jdavidrcamacho/gpyrn/wiki).

<br/>
<br/>
<br/>
<br/>
<br/>
<br/>
<br/>

***
